==> kbib_0.6.1.orig.tar.gz: kbib-0.6.1/kbib/kbibcreatebiliographydlg.h <==
/***************************************************************************
                          kbibcreatebiliographydlg  -  description
                             -------------------
    begin                : Thu Nov 25 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <kdialogbase.h>

#include <klineedit.h>
#include <kpushbutton.h>
#include <qlabel.h>
#include <kcombobox.h>
#include <qtextedit.h>

#ifndef KBIBCREATEBILIOGRAPHYDLG_H
#define KBIBCREATEBILIOGRAPHYDLG_H


/**
@author Thach Nguyen
*/
class KBibCreateBiliographyDlg : public KDialogBase
{
  Q_OBJECT
public:
  KBibCreateBiliographyDlg(QWidget *parent = 0, const char *name = 0);

  ~KBibCreateBiliographyDlg();
  QString getBibStyle();
  QString getAdditionalFile();

private:
  KPushButton *browseBttn;
  QLabel *label;
  KComboBox  *bibStyle;
  KLineEdit  *additionalFile;
  QLabel *additionalFileLabel;
  KPushButton *additionalFilebrowseBttn;

public slots:
  void slotBrowseBttn();
  void slotAdditionalFilebrowseBttn();

};


#endif

#ifndef KBIBBILIOGRAPHYDLG_H
#define KBIBBILIOGRAPHYDLG_H


class KBibBiliographyDlg : public KDialogBase
{
  Q_OBJECT
public:
  KBibBiliographyDlg(QWidget *parent = 0, const char *name = 0);

  ~KBibBiliographyDlg();
  void setText(QString st);

public slots:
  void slotCopyBttn();

private:
  QLabel *label;
  QTextEdit *textView;
  KPushButton *copyBttn;

};


#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbibcreatebiliographydlg.h <==
/***************************************************************************
                          kbibcreatebiliographydlg  -  description
                             -------------------
    begin                : Thu Nov 25 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <kdialogbase.h>

#include <klineedit.h>
#include <kpushbutton.h>
#include <qlabel.h>
#include <kcombobox.h>
#include <qtextedit.h>

#ifndef KBIBCREATEBILIOGRAPHYDLG_H
#define KBIBCREATEBILIOGRAPHYDLG_H


/**
@author Thach Nguyen
*/
class KBibCreateBiliographyDlg : public KDialogBase
{
  Q_OBJECT
public:
  KBibCreateBiliographyDlg(QWidget *parent = 0, const char *name = 0);

  ~KBibCreateBiliographyDlg();
  QString getBibStyle();
  QString getAdditionalFile();

private:
  KPushButton *browseBttn;
  QLabel *label;
  KComboBox  *bibStyle;
  KLineEdit  *additionalFile;
  QLabel *additionalFileLabel;
  KPushButton *additionalFilebrowseBttn;

public slots:
  void slotBrowseBttn();
  void slotAdditionalFilebrowseBttn();

};


#endif

#ifndef KBIBBILIOGRAPHYDLG_H
#define KBIBBILIOGRAPHYDLG_H


class KBibBiliographyDlg : public KDialogBase
{
  Q_OBJECT
public:
  KBibBiliographyDlg(QWidget *parent = 0, const char *name = 0);

  ~KBibBiliographyDlg();
  void setText(QString st);

public slots:
  void slotCopyBttn();

private:
  QLabel *label;
  QTextEdit *textView;
  KPushButton *copyBttn;

};


#endif
